Stan Math Library: stan/math/fwd/mat/fun/log_determinant.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

log_determinant.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_MAT_FUN_LOG_DETERMINANT_HPP
2 #define STAN_MATH_FWD_MAT_FUN_LOG_DETERMINANT_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/fwd/core.hpp>
6 #include <stan/math/fwd/mat/fun/typedefs.hpp>
7 #include <stan/math/fwd/mat/fun/determinant.hpp>
8 #include <stan/math/fwd/scal/fun/fabs.hpp>
9 #include <stan/math/fwd/scal/fun/log.hpp>
10 #include <stan/math/prim/mat/err/check_square.hpp>
11 #include <boost/math/tools/promotion.hpp>
12 #include <vector>
13
14 namespace stan {
15 namespace math {
16
17 template<typename T, int R, int C>
18 inline
19 fvar<T>
20 log_determinant(const Eigen::Matrix<fvar<T>, R, C>& m) {
21 stan::math::check_square("log_determinant", "m", m);
22
23 return stan::math::log(stan::math::fabs(stan::math::determinant(m)));
24 }
25 }
26 }
27 #endif
typedefs.hpp
core.hpp
stan::math::fabs
fvar< T > fabs(const fvar< T > &x)
Definition: fabs.hpp:14
log.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::log
fvar< T > log(const fvar< T > &x)
Definition: log.hpp:15
fabs.hpp
stan::math::log_determinant
fvar< T > log_determinant(const Eigen::Matrix< fvar< T >, R, C > &m)
Definition: log_determinant.hpp:20
determinant.hpp
stan::math::determinant
fvar< T > determinant(const Eigen::Matrix< fvar< T >, R, C > &m)
Definition: determinant.hpp:21
Eigen.hpp
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
stan::math::fvar
Definition: fvar.hpp:13
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.